@@ -1,7 +1,8 @@
 """Airzone library common code."""
+
 from __future__ import annotations
 
-from enum import IntEnum
+from enum import Enum, IntEnum
 from typing import Any
 
 
@@ -37,6 +38,20 @@ class AirzoneStages(IntEnum):
         return []
 
 
+class EcoAdapt(str, Enum):
+    """Airzone Eco-Adapt."""
+
+    OFF = "off"
+    MANUAL = "manual"
+    A = "a"
+    A_PLUS = "a_p"
+    A_PLUS_PLUS = "a_pp"
+
+    @classmethod
+    def _missing_(cls, value: Any) -> EcoAdapt:
+        return cls.OFF
+
+
 class GrilleAngle(IntEnum):
     """Airzone grille angles."""
 
@@ -50,6 +65,17 @@ class GrilleAngle(IntEnum):
         return cls.DEG_90
 
 
+class OperationAction(IntEnum):
+    """Airzone operation actions."""
+
+    COOLING = 1
+    DRYING = 2
+    FAN = 3
+    HEATING = 4
+    IDLE = 5
+    OFF = 6
+
+
 class OperationMode(IntEnum):
     """Airzone operation modes."""
 
@@ -67,6 +93,20 @@ class OperationMode(IntEnum):
         return cls.UNKNOWN
 
 
+class HotWaterOperation(IntEnum):
+    """Airzone Hot Water operations."""
+
+    UNKNOWN = -1
+
+    Off = 0
+    On = 1
+    Powerful = 2
+
+    @classmethod
+    def _missing_(cls, value: Any) -> HotWaterOperation:
+        return cls.UNKNOWN
+
+
 class SleepTimeout(IntEnum):
     """Airzone sleep timeouts."""
 
@@ -189,3 +229,8 @@ class WebServerType(IntEnum):
             self.AIDOO: "Aidoo WebServer",
         }
         return models[self.value]
+
+
+def get_system_zone_id(system_id: int, zone_id: int) -> str:
+    """Combine system and zone IDs."""
+    return f"{system_id}:{zone_id}"
