@@ -1,4 +1,5 @@
 """Airzone library exceptions."""
+
 from __future__ import annotations
 
 
@@ -10,6 +11,14 @@ class APIError(AirzoneError):
     """Exception raised when API fails."""
 
 
+class HotWaterNotAvailable(AirzoneError):
+    """Exception raised when Hot Water is not available."""
+
+
+class IaqSensorNotAvailable(AirzoneError):
+    """Exception raised when IAQ sensor is not available."""
+
+
 class InvalidHost(AirzoneError):
     """Exception raised when invalid host is requested."""
 
